@@ -25,7 +25,7 @@ def md5sum(fname):
     return md5.hexdigest()
 
 
-def _urlretrieve(url, fname, cache):
+def _urlretrieve(url, fname, cache, ssl_context):
     # Get it
     print("Downloading", url)
 
@@ -67,7 +67,9 @@ def _urlretrieve(url, fname, cache):
 
         req = urllib.request.Request(url, headers=headers)
 
-        with contextlib.closing(urllib.request.urlopen(req)) as rfp:
+        with contextlib.closing(
+            urllib.request.urlopen(req, context=ssl_context)
+        ) as rfp:
             headers = rfp.info()
 
             with open(fname, "wb") as fp:
